@@ -7,6 +7,8 @@ if [[ "${build_platform}" == "win-64" ]]; then
     DOTNET_ROOT="${PREFIX}/dotnet"
 else
     DOTNET_ROOT="${PREFIX}/lib/dotnet"
+    cp $RECIPE_DIR/dotnet.bash $PREFIX/bin/dotnet
+    chmod +x $PREFIX/bin/dotnet
 fi
 
 mkdir -p "${DOTNET_ROOT}"
